@@ -20,6 +20,14 @@ Math.units = function(x, ...) {
   OK <- switch(.Generic, "abs" = , "sign" = , "floor" = , "ceiling" = , "log" = ,
                "trunc" = , "round" = , "signif" = , "cumsum" = , 
                "cummax" = , "cummin" = TRUE, FALSE)
+
+  rad <- NULL # satisfy codetools warning
+  if (!OK && units(x) == units(set_units(1, rad))) {
+    OK <- switch(.Generic, "sin" = , "cos" = , "tan" = TRUE, FALSE)
+    if (OK)
+	  x <- set_units(x, unitless)
+  }
+
   if (!OK) {
     warning(paste("Operation", .Generic, "not meaningful for units"))
     x = unclass(x)
@@ -39,7 +47,7 @@ Math.units = function(x, ...) {
         u = paste0("lb(",units(x),")")
       else
         stop(paste("log with base", dts$base, "not supported"))
-      .as.units(NextMethod(.Generic), u)
+      .as.units(NextMethod(.Generic), units(make_unit(u)))
       # nocov end
     } else
       .as.units(NextMethod(.Generic), units(x))
